namedex package
===============

Submodules
----------

namedex.namedex module
----------------------

.. automodule:: namedex.namedex
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: namedex
    :members:
    :undoc-members:
    :show-inheritance:
